import debutantSimulations from "./debutant"
import intermediaireSimulations from "./intermediaire"
import avanceSimulations from "./avance"
import expertSimulations from "./expert"
import fautesGravesSimulations from "./fautes-graves"
import personnaliseSimulations from "./personnalise"
import examenSimulations from "./examen"

export const simulationLevels = [
  {
    id: "debutant",
    title: "Niveau débutant",
    icon: "🎖️",
    description: "Idéal pour commencer votre apprentissage du code de la route",
    color: "bg-emerald-50 border-emerald-200 hover:border-emerald-300",
    iconBg: "bg-emerald-100",
    buttonColor: "bg-emerald-600 hover:bg-emerald-700",
    count: debutantSimulations.length,
    questions: 20,
    duration: "20 minutes",
    simulations: debutantSimulations,
  },
  {
    id: "intermediaire",
    title: "Niveau intermédiaire",
    icon: "🥉",
    description: "Pour consolider vos connaissances de base",
    color: "bg-blue-50 border-blue-200 hover:border-blue-300",
    iconBg: "bg-blue-100",
    buttonColor: "bg-blue-600 hover:bg-blue-700",
    count: intermediaireSimulations.length,
    questions: 25,
    duration: "25 minutes",
    simulations: intermediaireSimulations,
  },
  {
    id: "avance",
    title: "Niveau avancé",
    icon: "🥈",
    description: "Pour les conducteurs qui maîtrisent déjà les bases",
    color: "bg-purple-50 border-purple-200 hover:border-purple-300",
    iconBg: "bg-purple-100",
    buttonColor: "bg-purple-600 hover:bg-purple-700",
    count: avanceSimulations.length,
    questions: 30,
    duration: "30 minutes",
    simulations: avanceSimulations,
  },
  {
    id: "expert",
    title: "Niveau expert",
    icon: "🥇",
    description: "Questions complexes pour tester vos connaissances approfondies",
    color: "bg-amber-50 border-amber-200 hover:border-amber-300",
    iconBg: "bg-amber-100",
    buttonColor: "bg-amber-600 hover:bg-amber-700",
    count: expertSimulations.length,
    questions: 35,
    duration: "35 minutes",
    simulations: expertSimulations,
  },
  {
    id: "fautes-graves",
    title: 'Niveau spécial "fautes graves"',
    icon: "⛔",
    description: "Concentrez-vous sur les erreurs qui peuvent être éliminatoires",
    color: "bg-red-50 border-red-200 hover:border-red-300",
    iconBg: "bg-red-100",
    buttonColor: "bg-red-600 hover:bg-red-700",
    count: fautesGravesSimulations.length,
    questions: 20,
    duration: "20 minutes",
    simulations: fautesGravesSimulations,
  },
  {
    id: "personnalise",
    title: "Entraînement personnalisé",
    icon: "🏅",
    description: "Créez votre propre simulation en fonction de vos besoins",
    color: "bg-indigo-50 border-indigo-200 hover:border-indigo-300",
    iconBg: "bg-indigo-100",
    buttonColor: "bg-indigo-600 hover:bg-indigo-700",
    count: personnaliseSimulations.length,
    questions: "Variable",
    duration: "Variable",
    simulations: personnaliseSimulations,
  },
  {
    id: "examen",
    title: "Examen",
    icon: "🏆",
    description: "Simulation complète dans les conditions réelles de l'examen",
    color: "bg-gray-50 border-gray-200 hover:border-gray-300",
    iconBg: "bg-gray-100",
    buttonColor: "bg-gray-800 hover:bg-gray-900",
    count: examenSimulations.length,
    questions: 40,
    duration: "40 minutes",
    simulations: examenSimulations,
  },
]

export const getAllSimulations = () => {
  return simulationLevels
}

export const getSimulationsByLevel = (levelId: string) => {
  const level = simulationLevels.find((level) => level.id === levelId)
  return level ? level.simulations : []
}

export const getSimulationById = (simulationId: string) => {
  for (const level of simulationLevels) {
    const simulation = level.simulations.find((sim) => sim.id === simulationId)
    if (simulation) {
      return { simulation, level }
    }
  }
  return null
}
